@@ -11,4 +11,6 @@ public interface SDLConstants extends SysConstants,
 	EventConstants, CDConstants, JoystickConstants,
 	KeyboardConstants, MouseConstants, VideoConstants
 {
+	int SDL_LIL_ENDIAN = 1234;
+	int SDL_BIG_ENDIAN = 4321;
 }
