@@ -9,14 +9,5 @@ using namespace sdl4gcj;
 SDLException::getError()
 {
 	JvInitClass(&sdl4gcj::SDLException::class$);
-	::java::lang::String *error = NULL;
-	char* nativeError = NULL;
-
-	nativeError = SDL_GetError();
-	if (nativeError)
-	{
-		error = JvNewStringLatin1(nativeError);
-	}
-
-	return error;
+	return JvNewStringLatin1(SDL_GetError());
 }
