@@ -70,6 +70,16 @@ public class Screen extends Surface
 	**/
 	public static native int[] getBlueGammaRamp();
 
+	/**
+	* SDL_GL_SetAttribute(SDL_GLattr attr, int value)
+	**/
+	public static native void glSetAttribute(int attr, int value);
+
+	/**
+	* SDL_GL_GetAttribute(SDL_GLattr attr)
+	**/
+	public static native int glGetAttribute(int attr);
+
 	// class variables
 	private static Screen singleton = null;
 
@@ -108,8 +118,17 @@ public class Screen extends Surface
 	**/
 	public native void updateRects(Rect[] rects);
 
+	/**
+	* SDL_Flip(SDL_Surface* screen)
+	**/
 	public native void flip();
 
+	/**
+	* SDL_GL_SwapBuffers()
+	**/
+	public native void glSwapBuffers();
+
+
 	/**
 	* SDL_SetCursor(SDL_Cursor* cursor) 
 	**/
