@@ -1,3 +1,4 @@
+#include "java/lang/String.h"
 #include "sdl4gcj/video/Screen.h"
 #include "sdl4gcj/video/VideoInfo.h"
 #include "sdl4gcj/video/Rect.h"
@@ -6,6 +7,7 @@
 #include <stdlib.h>
 #include <gcj/cni.h>
 #include <SDL.h>
+#include <SDL_opengl.h>
 
 
 using namespace sdl4gcj::video;
@@ -25,7 +27,7 @@ Screen::setVideoMode (jint width, jint height, jint bpp, jint flags)
 	JvInitClass(&Screen::class$);
 	Screen* result = NULL;
 
-	SDL_Surface* screen = SDL_SetVideoMode(width, height, bpp, flags);
+	SDL_Surface* screen = ::SDL_SetVideoMode(width, height, bpp, flags);
 	if (screen != NULL)
 		result = Screen::getVideoSurface();
 	return result;
@@ -55,7 +57,7 @@ Screen::getVideoInfo ()
 	VideoInfo* videoInfo = NULL;
 	const SDL_VideoInfo* native = NULL;
 
-	native = SDL_GetVideoInfo();
+	native = ::SDL_GetVideoInfo();
 	videoInfo = new VideoInfo();
 	videoInfo->implementation = (::gnu::gcj::RawData*)native;
 
@@ -67,7 +69,7 @@ Screen::setGamma (jfloat redgamma, jfloat greengamma, jfloat bluegamma)
 {
 	JvInitClass(&Screen::class$);
 
-	int result = SDL_SetGamma(redgamma, greengamma, bluegamma);
+	int result = ::SDL_SetGamma(redgamma, greengamma, bluegamma);
 	if (result == -1) throw new SDLException();
 
 	return ;
@@ -99,7 +101,7 @@ Screen::setGammaRamp (jintArray redArray, jintArray greenArray, jintArray blueAr
 		}
 	}
 
-	int result = SDL_SetGammaRamp(arguments[0], 
+	int result = ::SDL_SetGammaRamp(arguments[0], 
 		arguments[1], arguments[2]);
 	if (result == -1) throw new SDLException();
 
@@ -113,7 +115,7 @@ Screen::getRedGammaRamp ()
 	JvInitClass(&Screen::class$);
 
 	Uint16 redTable[256];
-	SDL_GetGammaRamp(redTable, NULL, NULL);
+	::SDL_GetGammaRamp(redTable, NULL, NULL);
 
 	jintArray gammaRampArray = JvNewIntArray(256);
 	jint* gammaRamp = elements(gammaRampArray);
@@ -129,7 +131,7 @@ Screen::getGreenGammaRamp ()
 	JvInitClass(&Screen::class$);
 
 	Uint16 greenTable[256];
-	SDL_GetGammaRamp(NULL, greenTable, NULL);
+	::SDL_GetGammaRamp(NULL, greenTable, NULL);
 
 	jintArray gammaRampArray = JvNewIntArray(256);
 	jint* gammaRamp = elements(gammaRampArray);
@@ -145,7 +147,7 @@ Screen::getBlueGammaRamp ()
 	JvInitClass(&Screen::class$);
 
 	Uint16 blueTable[256];
-	SDL_GetGammaRamp(NULL, NULL, blueTable);
+	::SDL_GetGammaRamp(NULL, NULL, blueTable);
 
 	jintArray gammaRampArray = JvNewIntArray(256);
 	jint* gammaRamp = elements(gammaRampArray);
@@ -155,6 +157,22 @@ Screen::getBlueGammaRamp ()
 	return gammaRampArray;
 }
 
+void
+Screen::glSetAttribute (jint attr, jint value)
+{
+	::SDL_GL_SetAttribute((SDL_GLattr)attr, value);
+}
+
+
+jint
+Screen::glGetAttribute (jint attr)
+{
+	int value;
+	::SDL_GL_GetAttribute((SDL_GLattr)attr, &value);
+
+	return (jint)value;
+}
+
 
 // instance methods
 
@@ -164,7 +182,7 @@ Screen::updateRect (jint x, jint y, jint w, jint h)
 	if (this->implementation == NULL) throw createIllegalStateScreenException();
 	SDL_Surface* nativeScreen = (SDL_Surface*)this->implementation;
 
-	SDL_UpdateRect(nativeScreen, x, y, w, h);
+	::SDL_UpdateRect(nativeScreen, x, y, w, h);
 }
 
 
@@ -196,7 +214,7 @@ Screen::updateRects (JArray< ::sdl4gcj::video::Rect *> *rectArray)
 		}
 	}
 
-	SDL_UpdateRects(nativeScreen, length, nativeRects);
+	::SDL_UpdateRects(nativeScreen, length, nativeRects);
 }
 
 void 
@@ -205,8 +223,15 @@ Screen::flip()
 	if (this->implementation == NULL) throw createIllegalStateScreenException();
 	SDL_Surface* nativeScreen = (SDL_Surface*)this->implementation;
 
-	int result = SDL_Flip(nativeScreen);
+	int result = ::SDL_Flip(nativeScreen);
 	if (result == -1) new SDLException();
 }
 
 
+void
+Screen::glSwapBuffers ()
+{
+	::SDL_GL_SwapBuffers();
+}
+
+
